@@ -1,17 +1,26 @@
 import re
 import sys
+import warnings
 from collections import namedtuple
 
 from .connection import connect, Connection, TIMEOUT as DEFAULT_TIMEOUT
 from .cursor import Cursor
 from .pool import create_pool, Pool
 from .transaction import IsolationLevel, Transaction
+from .utils import get_running_loop
 
-__all__ = ('connect', 'create_pool', 'Connection', 'Cursor', 'Pool',
-           'version', 'version_info', 'DEFAULT_TIMEOUT', 'IsolationLevel',
-           'Transaction')
+warnings.filterwarnings(
+    'always', '.*',
+    category=ResourceWarning,
+    module=r'aiopg(\.\w+)+',
+    append=False
+)
 
-__version__ = '0.16.0'
+__all__ = ('connect', 'create_pool', 'get_running_loop',
+           'Connection', 'Cursor', 'Pool', 'version', 'version_info',
+           'DEFAULT_TIMEOUT', 'IsolationLevel', 'Transaction')
+
+__version__ = '1.0.0'
 
 version = __version__ + ' , Python ' + sys.version
 
@@ -20,26 +29,30 @@ VersionInfo = namedtuple('VersionInfo',
 
 
 def _parse_version(ver):
-    RE = (r'^(?P<major>\d+)\.(?P<minor>\d+)\.'
-          '(?P<micro>\d+)((?P<releaselevel>[a-z]+)(?P<serial>\d+)?)?$')
+    RE = (
+        r'^'
+        r'(?P<major>\d+)\.(?P<minor>\d+)\.(?P<micro>\d+)'
+        r'((?P<releaselevel>[a-z]+)(?P<serial>\d+)?)?'
+        r'$'
+    )
     match = re.match(RE, ver)
     try:
         major = int(match.group('major'))
         minor = int(match.group('minor'))
         micro = int(match.group('micro'))
-        levels = {'c': 'candidate',
+        levels = {'rc': 'candidate',
                   'a': 'alpha',
                   'b': 'beta',
                   None: 'final'}
         releaselevel = levels[match.group('releaselevel')]
         serial = int(match.group('serial')) if match.group('serial') else 0
         return VersionInfo(major, minor, micro, releaselevel, serial)
-    except Exception:
-        raise ImportError("Invalid package version {}".format(ver))
+    except Exception as e:
+        raise ImportError("Invalid package version {}".format(ver)) from e
 
 
 version_info = _parse_version(__version__)
 
 # make pyflakes happy
 (connect, create_pool, Connection, Cursor, Pool, DEFAULT_TIMEOUT,
- IsolationLevel, Transaction)
+ IsolationLevel, Transaction, get_running_loop)
